@@ -4,6 +4,7 @@ from django.core.exceptions import ValidationError
 from django.db import models
 from django.utils.encoding import force_str
 
+from timezone_field.choices import standard, with_gmt_offset
 from timezone_field.utils import is_pytz_instance, add_gmt_offset_to_choices
 
 
@@ -35,11 +36,9 @@ class TimeZoneField(models.Field):
 
     # NOTE: these defaults are excluded from migrations. If these are changed,
     #       existing migration files will need to be accomodated.
-    CHOICES = [
-        (pytz.timezone(tz), tz.replace('_', ' '))
-        for tz in pytz.common_timezones
-    ]
-    MAX_LENGTH = 63
+    default_tzs = [pytz.timezone(tz) for tz in pytz.common_timezones]
+    default_choices = standard(default_tzs)
+    default_max_length = 63
 
     def __init__(self, *args, **kwargs):
         # allow some use of positional args up until the args we customize
@@ -47,30 +46,45 @@ class TimeZoneField(models.Field):
         # https://github.com/django/django/blob/1.11.11/django/db/models/fields/__init__.py#L145
         if len(args) > 3:
             raise ValueError('Cannot specify max_length by positional arg')
+        kwargs.setdefault('max_length', self.default_max_length)
 
-        kwargs.setdefault('choices', self.CHOICES)
-        kwargs.setdefault('max_length', self.MAX_LENGTH)
-        kwargs.setdefault('display_GMT_offset', False)
+        if 'choices' in kwargs:
+            values, displays = zip(*kwargs['choices'])
+            # Choices can be specified in two forms: either
+            # [<pytz.timezone>, <str>] or [<str>, <str>]
+            #
+            # The [<pytz.timezone>, <str>] format is the one we actually
+            # store the choices in memory because of
+            # https://github.com/mfogel/django-timezone-field/issues/24
+            #
+            # The [<str>, <str>] format is supported because since django
+            # can't deconstruct pytz.timezone objects, migration files must
+            # use an alternate format. Representing the timezones as strings
+            # is the obvious choice.
+            if not is_pytz_instance(values[0]):
+                values = [pytz.timezone(v) for v in values]
+        else:
+            values = self.default_tzs
+            displays = None
 
-        # Choices can be specified in two forms: either
-        # [<pytz.timezone>, <str>] or [<str>, <str>]
-        #
-        # The [<pytz.timezone>, <str>] format is the one we actually
-        # store the choices in memory because of
-        # https://github.com/mfogel/django-timezone-field/issues/24
-        #
-        # The [<str>, <str>] format is supported because since django
-        # can't deconstruct pytz.timezone objects, migration files must
-        # use an alternate format. Representing the timezones as strings
-        # is the obvious choice.
-        choices = kwargs['choices']
-        if isinstance(choices[0][0], (str, bytes)):
-            kwargs['choices'] = [(pytz.timezone(n1), n2) for n1, n2 in choices]
+        choices_display = kwargs.pop('choices_display', None)
+        if choices_display == 'WITH_GMT_OFFSET':
+            choices = with_gmt_offset(values)
+        elif choices_display == 'STANDARD':
+            choices = standard(values)
+        elif choices_display is None:
+            choices = zip(values, displays) if displays else standard(values)
+        else:
+            raise ValueError(
+                "Unrecognized value for kwarg 'choices_display' of '"
+                + choices_display + "'"
+            )
 
-        if kwargs['display_GMT_offset']:
-            kwargs['choices'] = add_gmt_offset_to_choices(kwargs['choices'])
-        kwargs.pop('display_GMT_offset', None)
+        # 'display_GMT_offset' is deprecated, use 'choices_display' instead
+        if kwargs.pop('display_GMT_offset', False):
+            choices = add_gmt_offset_to_choices(choices)
 
+        kwargs['choices'] = choices
         super(TimeZoneField, self).__init__(*args, **kwargs)
 
     def validate(self, value, model_instance):
@@ -80,16 +94,15 @@ class TimeZoneField(models.Field):
 
     def deconstruct(self):
         name, path, args, kwargs = super(TimeZoneField, self).deconstruct()
-        if kwargs.get('choices') == self.CHOICES:
+        if kwargs.get('choices') == self.default_choices:
             del kwargs['choices']
-        if kwargs.get('max_length') == self.MAX_LENGTH:
+        if kwargs.get('max_length') == self.default_max_length:
             del kwargs['max_length']
 
         # django can't decontruct pytz objects, so transform choices
         # to [<str>, <str>] format for writing out to the migration
         if 'choices' in kwargs:
             kwargs['choices'] = [(tz.zone, n) for tz, n in kwargs['choices']]
-
         return name, path, args, kwargs
 
     def get_internal_type(self):
